@@ -14,5 +14,5 @@
 core_metadata <- function(tsn, wt = "json", raw = FALSE, ...) {
   out <- itis_GET("getCoreMetadataFromTSN", list(tsn = tsn), wt, ...)
   if (raw || wt == "xml") return(out)
-  dr_op(tibble::as_data_frame(parse_raw(out)), "class")
+  dr_op(tibble::as_tibble(parse_raw(out)), "class")
 }
