@@ -14,7 +14,7 @@ parent_tsn <- function(tsn, wt = "json", raw = FALSE, ...) {
   if (raw || wt == "xml") return(out)
   x <- parse_raw(out)
   res <- tc(pick_cols(x, c("parentTsn", "tsn")))
-  tibble::as_data_frame(
+  tibble::as_tibble(
     if (length(names(res)) == 1) NULL else res
   )
 }
